"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const fs = require("fs");
const fse = require("fs-extra");
const jsYaml = require("js-yaml");
const path = require("path");
class default_1 extends command_1.default {
    async init() {
        // If config file does not exists, initialize it:
        fse.ensureDirSync(this.config.configDir);
        if (!fs.existsSync(path.join(this.config.configDir, 'config.yml'))) {
            const defaultConfig = {
                elasticsearch: {
                    port: 9200,
                    // tslint:disable-next-line:no-http-string
                    host: 'http://127.0.0.1',
                    indices: {
                        repos: 'gh_repos',
                        issues: 'gh_issues_',
                        projects: 'gh_projects_',
                        labels: 'gh_labels_',
                        milestones: 'gh_milestones_',
                        prs: 'gh_prs_',
                    }
                },
                fetch: {
                    max_nodes: 30
                },
                github: {
                    token: 'TOKEN_HERE'
                }
            };
            fs.writeFileSync(path.join(this.config.configDir, 'config.yml'), jsYaml.safeDump(defaultConfig));
            this.log('Initialized configuration file with defaults in: ' + path.join(this.config.configDir, 'config.yml'));
        }
        else {
            this.log('Configuration file exists: ' + path.join(this.config.configDir, 'config.yml'));
        }
    }
}
default_1.flags = {
    esport: command_1.flags.string({
        required: false,
        env: 'ES_PORT',
        description: 'Elastic search port'
    }),
    eshost: command_1.flags.string({
        required: false,
        env: 'ES_HOST',
        // tslint:disable-next-line:no-http-string
        description: 'Elastic search host'
    }),
    esrepo: command_1.flags.string({
        required: false,
        env: 'ES_REPO',
        // tslint:disable-next-line:no-http-string
        description: 'Elastic index containing the GitHub repository'
    }),
    gtoken: command_1.flags.string({
        required: false,
        env: 'GITHUB_TOKEN',
        // tslint:disable-next-line:no-http-string
        description: 'GitHub user Token'
    }),
};
exports.default = default_1;
