"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const apollo_cache_inmemory_1 = require("apollo-cache-inmemory");
const apollo_client_1 = require("apollo-client");
const apollo_link_1 = require("apollo-link");
const apollo_link_http_1 = require("apollo-link-http");
const cli_ux_1 = require("cli-ux");
const fs_1 = require("fs");
const node_fetch_1 = require("node-fetch");
const graphqlQuery_1 = require("../utils/graphqlQuery");
class FetchRepo {
    constructor(log, userConfig, cli) {
        this.githubToken = userConfig.github.token;
        this.githubLogin = userConfig.github.login;
        this.maxQueryIncrement = parseInt(userConfig.fetch.max_nodes, 10);
        this.log = log;
        this.cli = cli;
        this.fetchedRepos = [];
        this.errorRetry = 0;
        this.getSingleRepo = fs_1.readFileSync(__dirname + '/../graphql/getSingleRepo.graphql', 'utf8');
        this.rateLimit = {
            limit: 5000,
            cost: 1,
            remaining: 5000,
            resetAt: null
        };
        const httpLink = new apollo_link_http_1.HttpLink({ uri: 'https://api.github.com/graphql', fetch: node_fetch_1.default });
        const cache = new apollo_cache_inmemory_1.InMemoryCache();
        //const cache = new InMemoryCache().restore(window.__APOLLO_STATE__)
        const authMiddleware = new apollo_link_1.ApolloLink((operation, forward) => {
            // add the authorization to the headers
            operation.setContext({
                headers: {
                    authorization: this.githubToken ? `Bearer ${this.githubToken}` : '',
                }
            });
            return forward(operation).map((response) => {
                if (response.errors !== undefined && response.errors.length > 0) {
                    response.data.errors = response.errors;
                }
                return response;
            });
        });
        this.client = new apollo_client_1.default({
            link: apollo_link_1.concat(authMiddleware, httpLink),
            //link: authLink.concat(link),
            cache,
        });
    }
    async load(login, repo) {
        this.log('Started load');
        cli_ux_1.default.action.start('Loading repository: ' + login + '/' + repo);
        const data = await graphqlQuery_1.default(this.client, this.getSingleRepo, { org_name: login, repo_name: repo }, this.rateLimit, this.log);
        if (data.data.repository !== null) {
            let repoObj = JSON.parse(JSON.stringify(data.data.repository)); //TODO - Replace this with something better to copy object ?
            repoObj.org = {
                login: data.data.repository.owner.login,
                name: data.data.repository.owner.login,
                id: data.data.repository.owner.id,
                url: data.data.repository.owner.url,
            };
            this.fetchedRepos.push(repoObj);
        }
        else {
            this.log('ERROR: Either this repository does not exist, or you do not have the necessary permissions');
        }
        cli_ux_1.default.action.stop(' completed');
        return this.fetchedRepos;
    }
}
exports.default = FetchRepo;
