"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const apollo_cache_inmemory_1 = require("apollo-cache-inmemory");
const apollo_client_1 = require("apollo-client");
const apollo_link_1 = require("apollo-link");
const apollo_link_http_1 = require("apollo-link-http");
const node_fetch_1 = require("node-fetch");
async function initApolloClient(githubToken) {
    const httpLink = new apollo_link_http_1.HttpLink({ uri: 'https://api.github.com/graphql', fetch: node_fetch_1.default });
    const cache = new apollo_cache_inmemory_1.InMemoryCache();
    //const cache = new InMemoryCache().restore(window.__APOLLO_STATE__)
    const authMiddleware = new apollo_link_1.ApolloLink((operation, forward) => {
        // add the authorization to the headers
        operation.setContext({
            headers: {
                authorization: githubToken ? `Bearer ${githubToken}` : '',
            }
        });
        return forward(operation).map((response) => {
            if (response !== undefined && response.errors.length > 0) {
                response.data.errors = response.errors;
            }
            return response;
        });
    });
    const client = await new apollo_client_1.default({
        link: apollo_link_1.concat(authMiddleware, httpLink),
        //link: authLink.concat(link),
        cache,
    });
    return client;
}
exports.default = initApolloClient;
